"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.faceAuth = faceAuth;
exports.init = init;
var _reactNative = require("react-native");
var _reactNativeFs = _interopRequireDefault(require("react-native-fs"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const LINKING_ERROR = `The package 'mosip-inji-face-sdk' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo managed workflow\n';
const MosipInjiFaceSdk = _reactNative.NativeModules.MosipInjiFaceSdk ? _reactNative.NativeModules.MosipInjiFaceSdk : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
function faceAuth(capturedImage, vcImage) {
  return MosipInjiFaceSdk.faceAuth(capturedImage, vcImage);
}
async function init(url, overrideCache) {
  try {
    console.log('inside inji face sdk init function, url is - ' + url);
    const modelFilePath = `${_reactNativeFs.default.CachesDirectoryPath}/model.tflite`;
    const checksumCachePath = `${_reactNativeFs.default.CachesDirectoryPath}/model.sha256`;
    var fileExists = await _reactNativeFs.default.exists(modelFilePath);

    // checking if file is alredy present and downloaded properly
    fileExists = await doesModelExist(fileExists, overrideCache, modelFilePath, checksumCachePath);
    if (!fileExists || overrideCache) {
      let checksumDownloadResult = await downloadFile(url + '/model.sha256', checksumCachePath);
      console.log('Checksum file download status code = ' + checksumDownloadResult.statusCode);
      let downloadRes = await downloadFile(url + '/model.tflite', modelFilePath);
      console.log('Model File download size = ' + downloadRes.bytesWritten);
      var checksum = await _reactNativeFs.default.readFile(checksumCachePath);
      checksum = checksum.replace(/\s/g, "");
      var actualModelChecksum = await _reactNativeFs.default.hash(modelFilePath, 'sha256');
      console.log('checksum calculated from file = ' + actualModelChecksum);
      console.log('checksum received from server = ' + checksum.replace(/\s/g, ""));
      if (actualModelChecksum === checksum) {
        return Promise.resolve(true);
      }
    } else if (fileExists) {
      return Promise.resolve(true);
    }
  } catch (e) {
    console.error('Error occured downloading model from - ' + url);
    console.error(e);
  }
  return Promise.resolve(false);
}
async function doesModelExist(fileExists, overrideCache, fileDir, checksumCachePath) {
  if (fileExists && !overrideCache) {
    try {
      // compare checksum to verify if file downloaded successfully
      var checksum = await _reactNativeFs.default.readFile(checksumCachePath);
      checksum = checksum.replace(/\s/g, "");
      var fileData = await _reactNativeFs.default.hash(fileDir, 'sha256');
      console.log('file exists......so comparing checksum');
      if (checksum !== fileData) {
        fileExists = false;
      } else {
        fileExists = true;
      }
    } catch (e) {
      console.error(e);
      fileExists = false;
    }
  }
  return fileExists;
}
async function downloadFile(url, toFile) {
  let downloadRes = await _reactNativeFs.default.downloadFile({
    fromUrl: url,
    toFile: toFile
  }).promise;
  return downloadRes;
}
//# sourceMappingURL=index.js.map